#!/bin/bash

# Copyright 2013 Google Inc. All rights reserved.
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.

test "${BUNDLE_DISPLAY_NAME}" = 'α	'
