// Copyright (c) 2013 Google Inc. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef TEST_LIBRARY_DIRS_SUBDIR_MYLIB_H
#define TEST_LIBRARY_DIRS_SUBDIR_MYLIB_H

#include <string>

std::string my_foo(int);

#endif  // TEST_LIBRARY_DIRS_SUBDIR_MYLIB_H
