; Copyright (c) 2012 Google Inc. All rights reserved.
; Use of this source code is governed by a BSD-style license that can be
; found in the LICENSE file.

; This is a placeholder. It should not be referenced if overrides work
; correctly.

Bad stuff that shouldn't assemble.
