// Copyright (c) 2013 Google Inc. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#if __cplusplus != 199711L
#error wrong c++ standard version
#endif

enum cxx11_keywords {
  alignas,
  alignof,
  char16_t,
  char32_t,
  constexpr,
  decltype,
  noexcept,
  nullptr,
  override,
  static_assert,
  thread_local,
};

int main() { return 0; }

