// Copyright (c) 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import "oaidl.idl";
import "bar.idl";

[
  object,
  uuid(9C1100DD-51D4-4827-AE9F-3B8FAC4AED72),
]
interface Foo : IUnknown {
  HRESULT FooFunction(Bar* bar);
};
