// Copyright (c) 2013 Google Inc. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// Stub so we can link with /NODEFAULTLIB when checking disasm.
int mainCRTStartup() {
  return 5;
}
