// Copyright (c) 2013 Google Inc. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "mylib.h"

std::string my_foo(int x) {
  return std::string("world");
}
