// Copyright (c) 2014 Google Inc. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#import <Foundation/Foundation.h>
#import <WatchKit/WatchKit.h>

@interface InterfaceController : WKInterfaceController
@end

