// Copyright (c) 2016 Google Inc. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE

#ifndef _WIN_DRIVER_TARGET_TYPE_H_
#define _WIN_DRIVER_TARGET_TYPE_H_

#include <ntifs.h>
#include <ntdddisk.h>

DRIVER_INITIALIZE DriverEntry;

#endif
